@@ -192,6 +192,8 @@ kipmsgWidget::kipmsgWidget(QWidget* parent, const char* name, WFlags fl)
 		IpMsgAgent->AddBroadcastAddress( broadcastAddress.data() );
 	}
 
+	IpMsgAgent->StartNetwork();
+
     MainPopup = new KPopupMenu(this);
 	AbsencePopup = new KPopupMenu(this);
 	rebuildMenu();
@@ -495,7 +497,11 @@ void kipmsgWidget::slotAboutClicked()
  */
 void kipmsgWidget::slotViewLogClicked()
 {
-	KRun::run( "kwrite --encoding utf8", QStringList( KIpMsgSettings::logFileName() ) );
+	if ( KIpMsgSettings::useExternalLogViewer() ) {
+		KRun::run( KIpMsgSettings::logViewerPath() + " " + KIpMsgSettings::logViewerOption(), QStringList( KIpMsgSettings::logFileName() ) );
+	} else {
+		KRun::run( "kwrite --encoding utf8", QStringList( KIpMsgSettings::logFileName() ) );
+	}
 }
 
 /**
